hierarch.stats
==============

.. automodule:: hierarch.stats

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      confidence_interval
      hierarchical_randomization
      hypothesis_test
      multi_sample_test
      studentized_covariance
      welch_statistic
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
      :toctree:
   
      ConvergenceWarning
   
   



